@@ -235,7 +235,9 @@ class MigrationOps(object):
             # make sure that the source is not a remote local path.
             # e.g.: \\win-srv\\C$\OpenStack\Instances\..
             # CSVs, local paths, and shares are fine.
-            inst_dir = source_inst_dir.rstrip('_revert')
+            # NOTE(claudiub): get rid of the final _revert part of the path.
+            # rstrip can remove more than _revert, which is not desired.
+            inst_dir = source_inst_dir.rsplit('_revert', 1)[0]
             LOG.warning(
                 'Host is configured not to copy disks on cold migration, but '
                 'the instance will not be able to start with the remote path: '
@@ -246,7 +248,7 @@ class MigrationOps(object):
         else:
             # make a copy on the source node's configured location.
             # strip the _revert from the source backup dir.
-            inst_dir = source_inst_dir.rstrip('_revert')
+            inst_dir = source_inst_dir.rsplit('_revert', 1)[0]
             self._pathutils.check_dir(inst_dir, create_dir=True)
 
         export_path = self._pathutils.get_export_dir(
@@ -279,8 +281,10 @@ class MigrationOps(object):
                              block_device_info, resize_instance=False):
         vm_gen = self._vmops.get_image_vm_generation(instance.uuid, image_meta)
         self._import_vm(instance_dir)
-        self._volumeops.connect_volumes(block_device_info)
+        self._vmops.update_vm_resources(instance, vm_gen, image_meta,
+                                        instance_dir, resize_instance)
 
+        self._volumeops.connect_volumes(block_device_info)
         self._update_disk_image_paths(instance, instance_dir)
         self._check_and_update_disks(context, instance, vm_gen, image_meta,
                                      block_device_info,
@@ -288,9 +292,6 @@ class MigrationOps(object):
         self._volumeops.fix_instance_volume_disk_paths(
             instance.name, block_device_info)
 
-        self._vmops.update_vm_resources(instance, vm_gen, image_meta,
-                                        instance_dir, resize_instance)
-
         self._migrationutils.realize_vm(instance.name)
 
         self._vmops.configure_remotefx(instance, vm_gen, resize_instance)
