@@ -276,9 +276,9 @@ class MigrationOpsTestCase(test_base.HyperVBaseTestCase):
         recon_parent_vhd.assert_called_once_with(
             mock.sentinel.diff_vhd_path, fake_base_vhd)
 
-    @ddt.data((False, '\\\\fake-srv\\C$\\inst_dir_revert', True),
-              (False, '\\\\fake-srv\\share_path\\inst_dir_revert'),
-              (True, 'C:\\fake_inst_dir_revert'))
+    @ddt.data((False, '\\\\fake-srv\\C$\\inst_dir_0000000e_revert', True),
+              (False, '\\\\fake-srv\\share_path\\inst_dir_0000000e_revert'),
+              (True, 'C:\\fake_inst_dir_0000000e_revert'))
     @ddt.unpack
     def test_migrate_disks_from_source(self, move_disks_on_migration,
                                        source_inst_dir, is_remote_path=False):
@@ -305,7 +305,7 @@ class MigrationOpsTestCase(test_base.HyperVBaseTestCase):
                 mock_instance.name, create_dir=True, remove_dir=True)
             expected_inst_dir = mock_get_inst_dir.return_value
         else:
-            expected_inst_dir = source_inst_dir.rstrip('_revert')
+            expected_inst_dir = source_inst_dir[0: - len('_revert')]
             self._migrationops._pathutils.check_dir.assert_called_once_with(
                 expected_inst_dir, create_dir=True)
 
@@ -362,6 +362,10 @@ class MigrationOpsTestCase(test_base.HyperVBaseTestCase):
         get_image_vm_gen.assert_called_once_with(mock_instance.uuid,
                                                  mock.sentinel.image_meta)
         mock_import_vm.assert_called_once_with(mock.sentinel.instance_dir)
+        self._migrationops._vmops.update_vm_resources.assert_called_once_with(
+            mock_instance, get_image_vm_gen.return_value,
+            mock.sentinel.image_meta, mock.sentinel.instance_dir,
+            mock.sentinel.resize_instance)
         self._migrationops._volumeops.connect_volumes.assert_called_once_with(
             mock.sentinel.block_device_info)
         mock_update_disk_image_paths.assert_called_once_with(
@@ -372,10 +376,6 @@ class MigrationOpsTestCase(test_base.HyperVBaseTestCase):
             resize_instance=mock.sentinel.resize_instance)
         self._volumeops.fix_instance_volume_disk_paths.assert_called_once_with(
             mock_instance.name, mock.sentinel.block_device_info)
-        self._migrationops._vmops.update_vm_resources.assert_called_once_with(
-            mock_instance, get_image_vm_gen.return_value,
-            mock.sentinel.image_meta, mock.sentinel.instance_dir,
-            mock.sentinel.resize_instance)
         self._migrationops._migrationutils.realize_vm.assert_called_once_with(
             mock_instance.name)
         self._migrationops._vmops.configure_remotefx.assert_called_once_with(
